@@ -134,8 +134,9 @@ def export(ctx, file):
         if scriptPath == "":
             scriptPath = os.path.abspath('.')
         sys.path.append(scriptPath)
-        from export import Export
-        ex = Export(ctx.obj)
+        print(sys.path)
+        from exportdfnsjkdfnsdkjfnsdjkf import Correspondence
+        ex = Correspondence(ctx.obj)
         ex.exec()
     except Exception as e:
         print(e)
